@@ -13,24 +13,21 @@ from .provider import SlackProvider
 class SlackOAuth2Adapter(OAuth2Adapter):
     provider_id = SlackProvider.id
 
-    access_token_url = 'https://slack.com/api/oauth.access'
-    authorize_url = 'https://slack.com/oauth/authorize'
-    identity_url = 'https://slack.com/api/users.identity'
+    access_token_url = "https://slack.com/api/oauth.access"
+    authorize_url = "https://slack.com/oauth/authorize"
+    identity_url = "https://slack.com/api/users.identity"
 
     def complete_login(self, request, app, token, **kwargs):
         extra_data = self.get_data(token.token)
-        return self.get_provider().sociallogin_from_response(request,
-                                                             extra_data)
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
     def get_data(self, token):
         # Verify the user first
-        resp = requests.get(
-            self.identity_url,
-            params={'token': token}
-        )
+        hed = {"Authorization": "Bearer " + token}
+        resp = requests.get(self.identity_url, headers=hed)
         resp = resp.json()
 
-        if not resp.get('ok'):
+        if not resp.get("ok"):
             raise OAuth2Error()
 
         return resp
