@@ -227,9 +227,14 @@ class OAuth2TestsMixin(object):
         response_json = self.get_login_response_json(
             with_refresh_token=with_refresh_token
         )
+        if isinstance(resp_mock, list):
+            resp_mocks = resp_mock
+        else:
+            resp_mocks = [resp_mock]
+
         with mocked_response(
             MockedResponse(200, response_json, {"content-type": "application/json"}),
-            resp_mock,
+            *resp_mocks,
         ):
             resp = self.client.get(complete_url, self.get_complete_parameters(q))
         return resp
@@ -279,8 +284,8 @@ class SocialAccountTests(TestCase):
         factory = RequestFactory()
         request = factory.get("/accounts/login/callback/")
         request.user = AnonymousUser()
-        SessionMiddleware().process_request(request)
-        MessageMiddleware().process_request(request)
+        SessionMiddleware(lambda request: None).process_request(request)
+        MessageMiddleware(lambda request: None).process_request(request)
 
         User = get_user_model()
         user = User()
@@ -371,8 +376,8 @@ class SocialAccountTests(TestCase):
         factory = RequestFactory()
         request = factory.get("/accounts/twitter/login/callback/")
         request.user = AnonymousUser()
-        SessionMiddleware().process_request(request)
-        MessageMiddleware().process_request(request)
+        SessionMiddleware(lambda request: None).process_request(request)
+        MessageMiddleware(lambda request: None).process_request(request)
 
         User = get_user_model()
         user = User()
@@ -408,8 +413,8 @@ class SocialAccountTests(TestCase):
         factory = RequestFactory()
         request = factory.get("/accounts/twitter/login/callback/")
         request.user = AnonymousUser()
-        SessionMiddleware().process_request(request)
-        MessageMiddleware().process_request(request)
+        SessionMiddleware(lambda request: None).process_request(request)
+        MessageMiddleware(lambda request: None).process_request(request)
         resp = complete_social_login(request, sociallogin)
         return request, resp
 
